SHA256
1
0
forked from pool/systemd

Accepting request 87397 from Base:System

- make sure updaters get in the /sbin/init from here - the sub package
  of the split package will decide which init wins in update case

- under openSUSE if it's not systemd, chances are good it's
  sysvinit

- do not list specific sbin_init providers

OBS-URL: https://build.opensuse.org/request/show/87397
OBS-URL: https://build.opensuse.org/package/show/openSUSE:Factory/systemd?expand=0&rev=74
This commit is contained in:
Lars Vogdt 2011-10-11 15:59:42 +00:00 committed by Git OBS Bridge
parent fc5292bb65
commit 135fa85fb7
3 changed files with 42 additions and 8 deletions

21
support-sysvinit.patch Normal file
View File

@ -0,0 +1,21 @@
Index: systemd-36/src/systemctl.c
===================================================================
--- systemd-36.orig/src/systemctl.c
+++ systemd-36/src/systemctl.c
@@ -4672,10 +4672,13 @@ static int parse_argv(int argc, char *ar
/* Hmm, so some other init system is
* running, we need to forward this
* request to it. For now we simply
- * guess that it is Upstart. */
-
- execv("/lib/upstart/telinit", argv);
+ * guess that it is Sysvinit or Upstart. */
+ if (!access("/lib/sysvinit/telinit", X_OK)) {
+ execv("/lib/sysvinit/telinit", argv);
+ } else {
+ execv("/lib/upstart/telinit", argv);
+ }
log_error("Couldn't find an alternative telinit implementation to spawn.");
return -EIO;
}

View File

@ -1,3 +1,20 @@
-------------------------------------------------------------------
Tue Oct 11 13:57:32 UTC 2011 - coolo@suse.com
- make sure updaters get in the /sbin/init from here - the sub package
of the split package will decide which init wins in update case
-------------------------------------------------------------------
Tue Oct 11 13:10:27 UTC 2011 - coolo@suse.com
- under openSUSE if it's not systemd, chances are good it's
sysvinit
-------------------------------------------------------------------
Tue Oct 11 11:07:02 UTC 2011 - coolo@suse.com
- do not list specific sbin_init providers
------------------------------------------------------------------- -------------------------------------------------------------------
Wed Oct 5 16:18:48 UTC 2011 - fcrozat@suse.com Wed Oct 5 16:18:48 UTC 2011 - fcrozat@suse.com

View File

@ -65,6 +65,7 @@ Patch6: 0001-handle-disable_caplock-and-compose_table-and-kbd_rat.patch
Patch8: tty1.patch Patch8: tty1.patch
Patch10: 0001-service-Fix-dependencies-added-when-parsing-insserv..patch Patch10: 0001-service-Fix-dependencies-added-when-parsing-insserv..patch
Patch13: 0001-service-flags-sysv-service-with-detected-pid-as-Rema.patch Patch13: 0001-service-flags-sysv-service-with-detected-pid-as-Rema.patch
Patch15: support-sysvinit.patch
# Upstream First - Policy: # Upstream First - Policy:
# Never add any patches to this package without the upstream commit id # Never add any patches to this package without the upstream commit id
@ -84,7 +85,6 @@ transactional dependency-based service control logic. It can work as a
drop-in replacement for sysvinit. drop-in replacement for sysvinit.
%package devel %package devel
License: GPLv2+
Group: Development/Libraries/C and C++ Group: Development/Libraries/C and C++
Summary: Development headers for systemd Summary: Development headers for systemd
Requires: %{name} = %{version} Requires: %{name} = %{version}
@ -94,13 +94,11 @@ Requires: pkg-config
Development headers and auxiliary files for developing applications for systemd. Development headers and auxiliary files for developing applications for systemd.
%package sysvinit %package sysvinit
License: GPLv2+
Group: System/Base
Summary: System V init tools Summary: System V init tools
Requires: %{name} = %{version} Requires: %{name} = %{version}
Provides: sbin_init Provides: sbin_init
Conflicts: sysvinit Conflicts: otherproviders(sbin_init)
Conflicts: upstart Provides: sysvinit:/sbin/init
%description sysvinit %description sysvinit
Drop-in replacement of System V init tools. Drop-in replacement of System V init tools.
@ -108,9 +106,6 @@ Drop-in replacement of System V init tools.
%if %{build_plymouth} %if %{build_plymouth}
%package plymouth %package plymouth
License: GPLv2+
Group: System/Base
Summary: Plymouth support for systemd Summary: Plymouth support for systemd
Requires: %{name} = %{version} Requires: %{name} = %{version}
Requires: plymouth Requires: plymouth
@ -128,6 +123,7 @@ Plymouth integration for systemd
%patch12 -p1 %patch12 -p1
%patch13 -p1 %patch13 -p1
%patch14 -p1 %patch14 -p1
%patch15 -p1
%build %build
autoreconf -fiv autoreconf -fiv